View source: R/design_matrices.R
| design_matrices | R Documentation |
mc_multinomFunction that builds the contrast and design matrices required by mc_multinom to parameterize, through multinomial logits, the initial and the transition probabilities of a Markov chain model.
design_matrices(k, nc, baseline, model_int, model_cov)
k |
Number of response categories (or observed states) in the Markov chain, coded as |
nc |
Number of covariates affecting the transition probabilities, excluding the intercept. Set |
baseline |
Character string specifying the reference category in the multinomial logit parameterization. With |
model_int |
Character string specifying the constraint structure for the intercepts of the transition logits. Possible values are:
|
model_cov |
Character string specifying the constraint structure for the regression coefficients of the transition covariates. The admissible values and their interpretation are the same as for |
G |
Contrast matrix used to parameterize the initial probabilities in the |
Z |
Design matrix mapping the reduced parameter vector to the transition-logit parameters under the selected intercept and covariate constraints |
GG |
Array of contrast matrices used to parameterize the transition probabilities for each origin state |
Z1 |
Design matrix defining the constraint structure for the intercepts of the transition logits |
Z2 |
Design matrix defining the constraint structure for the covariate effects on the transition logits. This component is returned only when |
Francesco Bartolucci, Silvia Pandolfi, University of Perugia (IT), Luca Brusa and Fulvia Pennoni, University of Milano-Bicocca (IT)
Bartolucci, F., Pandolfi, S., and Pennoni, F. (2026). Parsimonious parametrizations of transition matrices of Markov chain and hidden Markov models, Annals of Operations Research, 363, 233–266.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.